@@ -59,6 +59,7 @@ emoticons = {
 ":drapal:": "Drapal.png",
 ":-1:": "-1.png",
 ":+1:": "+1.png",
+":wedgeant:": "+1.png",
 ":ban:": "Ban.png",
 ":boulay:": "Boulay.png",
 ":thalis:": "Thalis.png",
@@ -94,6 +95,7 @@ emoticons = {
 ":kahn21:": "Kahn21.gif",
 ":adodonicoco:": "Adodonicoco.gif",
 ":totoz:": "Totoz.gif",
+":alph-one:": "Totoz.gif",
 ":prodigy:": "Prodigy.png",
 ":makokotte:": "Makokotte.gif",
 ":simchevelu:": "Simchevelu.gif",
@@ -108,6 +110,7 @@ emoticons = {
 ":dawacube:" : "DawaCube.gif",
 ":lol:": "Lol.gif",
 ":rofl:": "Rofl.gif",
+":rofl2:": "Rofl2.gif",
 ":toad666:" : "Toad666.gif",
 ":sarcastic:": "Sarcastic.gif",
 ":aloy:": "Aloy.png",
@@ -136,4 +139,32 @@ emoticons = {
 ":tristanf:": "TristanF.gif",
 ":itm:": "ITM.png",
 ":non:": "Non.gif",
+":gratgrat:": "Gratgrat.gif",
+":phenos:": "Phenos.png",
+":cosmoschtroumpf:": "Cosmoschtroumpf.png",
+":tibo2002:": "Tibo2002.png",
+":draculax:": "Draculax.png",
+":calin:": "Calin.gif",
+":briseparpaing:": "BriseParpaing.gif",
+":blessure:": "Blessure.png",
+":golden blessure:": "Golden_Blessure.png",
+":jaffax:": "Jaffax.png",
+":tarlooze:": "Tarlooze.gif",
+":jalouse:": "Jalouse.png",
+":classe++:": "Jalouse.png",
+":hfrbaxter:": "HFRBaxter.gif",
+":ninipc:": "NiniPC.gif",
+":sinking:": "Sinking.png",
+":nerd:": "Sinking.png",
+":xxantoinexx:": "Sinking.png",
+":sarko:": "Sarko.png",
+":delarue:": "Delarue.png",
+":delarue2:": "Delarue2.png",
+":delarue3:": "Delarue3.png",
+":delarue4:": "Delarue4.png",
+":delarue5:": "Delarue5.png",
+":delarue6:": "Delarue6.png",
+":wahoo:": "Wahoo.gif",
+":kryten:": "Kryten.png",
+":dtc:": "DTC.png",
 }
